@@ -130,8 +130,8 @@ impl Operator {
     /// await op.isExist("test");
     /// ```
     #[napi]
-    pub async fn is_exist(&self, path: String) -> Result<bool> {
-        self.0.is_exist(&path).await.map_err(format_napi_error)
+    pub async fn exists(&self, path: String) -> Result<bool> {
+        self.0.exists(&path).await.map_err(format_napi_error)
     }
 
     /// Check if this path exists or not synchronously.
@@ -141,8 +141,8 @@ impl Operator {
     /// op.isExistSync("test");
     /// ```
     #[napi]
-    pub fn is_exist_sync(&self, path: String) -> Result<bool> {
-        self.0.blocking().is_exist(&path).map_err(format_napi_error)
+    pub fn exists_sync(&self, path: String) -> Result<bool> {
+        self.0.blocking().exists(&path).map_err(format_napi_error)
     }
 
     /// Create dir with a given path.
@@ -464,7 +464,7 @@ impl Operator {
     /// ```
     #[napi]
     pub async fn remove(&self, paths: Vec<String>) -> Result<()> {
-        self.0.remove(paths).await.map_err(format_napi_error)
+        self.0.delete_iter(paths).await.map_err(format_napi_error)
     }
 
     /// Remove the path and all nested dirs and files recursively.
